@@ -115,8 +115,23 @@ TermDef       MyFrameTerms[] = {
     {TF_NO_MYNAME_PREPENDING, "TitleFocusedCompositionMethod", 28, TT_UINTEGER,   MYFRAME_TitleFCM_ID, NULL},
     {TF_NO_MYNAME_PREPENDING, "TitleUnfocusedCompositionMethod", 30, TT_UINTEGER,  MYFRAME_TitleUCM_ID, NULL},
     {TF_NO_MYNAME_PREPENDING, "TitleStickyCompositionMethod", 27, TT_UINTEGER,    MYFRAME_TitleSCM_ID, NULL},
-    {TF_NO_MYNAME_PREPENDING|TF_NONUNIQUE, "Inherit", 7, TT_QUOTED_TEXT,              MYFRAME_Inherit_ID, NULL},
-    {TF_NO_MYNAME_PREPENDING | TF_SYNTAX_TERMINATOR, "~MyFrame", 8, TT_FLAG, MYFRAME_DONE_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleFHue", 9,          TT_COLOR,         MYFRAME_TitleFHue_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleUHue", 9, 		   TT_COLOR,         MYFRAME_TitleUHue_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleSHue", 9,          TT_COLOR,         MYFRAME_TitleSHue_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleFocusedHue", 15,   TT_COLOR,         MYFRAME_TitleFHue_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleUnfocusedHue", 17, TT_COLOR,         MYFRAME_TitleUHue_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleStickyHue", 14,    TT_COLOR,         MYFRAME_TitleSHue_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleFSaturation", 16,  		  TT_UINTEGER,         MYFRAME_TitleFSat_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleUSaturation", 16, 		  TT_UINTEGER,         MYFRAME_TitleUSat_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleSSaturation", 16,    	  TT_UINTEGER,         MYFRAME_TitleSSat_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleFocusedSaturation", 22,   TT_UINTEGER,         MYFRAME_TitleFSat_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleUnfocusedSaturation", 24, TT_UINTEGER,         MYFRAME_TitleUSat_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleStickySaturation", 21,    TT_UINTEGER,         MYFRAME_TitleSSat_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleHSpacing", 13,    TT_INTEGER,         MYFRAME_TitleHSpacing_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "TitleVSpacing", 13,    TT_INTEGER,         MYFRAME_TitleVSpacing_ID, NULL},
+	{TF_NO_MYNAME_PREPENDING, "InheritDefaults", 15, TT_FLAG,              MYFRAME_InheritDefaults_ID, NULL},
+	{TF_NO_MYNAME_PREPENDING|TF_NONUNIQUE, "Inherit", 7, TT_QUOTED_TEXT,  MYFRAME_Inherit_ID, NULL},
+	{TF_NO_MYNAME_PREPENDING | TF_SYNTAX_TERMINATOR, "~MyFrame", 8, TT_FLAG, MYFRAME_DONE_ID, NULL},
     {TF_NO_MYNAME_PREPENDING, "LeftBtnBackground", 17,  TT_FILENAME,     MYFRAME_LeftBtnBackground_ID, NULL},
     {TF_NO_MYNAME_PREPENDING, "LeftSpacerBackground", 20,  TT_FILENAME,  MYFRAME_LeftSpacerBackground_ID, NULL},
     {TF_NO_MYNAME_PREPENDING, "LeftTitleSpacerBackground", 25,  TT_FILENAME,  MYFRAME_LTitleSpacerBackground_ID, NULL},
@@ -136,6 +151,8 @@ TermDef       MyFrameTerms[] = {
     {TF_NO_MYNAME_PREPENDING, "RightTitlebarLayout", 19,    TT_FLAG,   MYFRAME_RightTitlebarLayout_ID, &TbarLayoutSyntax},
     {TF_NO_MYNAME_PREPENDING, "NoBorder", 8,       			TT_FLAG,   MYFRAME_NoBorder_ID, NULL},
     {TF_NO_MYNAME_PREPENDING, "AllowBorder", 11,       		TT_FLAG,   MYFRAME_AllowBorder_ID, NULL},
+    {TF_NO_MYNAME_PREPENDING, "LeftBtnAlign", 12,           TT_FLAG,   MYFRAME_LeftBtnAlign_ID, &AlignSyntax},
+	{TF_NO_MYNAME_PREPENDING, "RightBtnAlign", 13,          TT_FLAG,   MYFRAME_RightBtnAlign_ID, &AlignSyntax},
 
 	{0, NULL, 0, 0, 0}
 };
@@ -356,6 +373,12 @@ ProcessMyFrameOptions (FreeStorageElem * options, MyFrameDefinition ** tail)
             {
                 if( options->term->id == MYFRAME_DONE_ID )
                     break;                     /* for loop */
+				if( options->term->id == MYFRAME_InheritDefaults_ID )
+				{
+                    set_flags( fd->flags, MYFRAME_INHERIT_DEFAULTS);
+					set_flags( fd->set_flags, MYFRAME_INHERIT_DEFAULTS);
+					continue;	
+				}	 
 				if( options->term->id >= MYFRAME_TitleBackgroundAlign_ID_START )
 				{
 					int index = options->term->id - MYFRAME_TitleBackgroundAlign_ID_START ;
@@ -390,6 +413,14 @@ ProcessMyFrameOptions (FreeStorageElem * options, MyFrameDefinition ** tail)
                         fd->title_align = ParseAlignOptions( options->sub );
                         set_flags( fd->set_title_attr, MYFRAME_TitleAlignSet );
                         break;
+					case MYFRAME_LeftBtnAlign_ID :
+                        fd->left_btn_align = ParseAlignOptions( options->sub );
+                        set_flags( fd->set_title_attr, MYFRAME_LeftBtnAlignSet );
+					    break ;
+					case MYFRAME_RightBtnAlign_ID :
+                        fd->right_btn_align = ParseAlignOptions( options->sub );
+                        set_flags( fd->set_title_attr, MYFRAME_RightBtnAlignSet );
+					    break ;
                     case MYFRAME_CondenseTitlebar_ID :
                         fd->condense_titlebar = ParseAlignOptions( options->sub );
                         set_flags( fd->set_title_attr, MYFRAME_CondenseTitlebarSet );
@@ -549,6 +580,35 @@ ProcessMyFrameOptions (FreeStorageElem * options, MyFrameDefinition ** tail)
                     fd->title_scm = item.data.integer;
                     set_flags( fd->set_title_attr, MYFRAME_TitleSCMSet );
                     break;
+                case MYFRAME_TitleFHue_ID :
+					set_string_value (&(fd->title_fhue), item.data.string, &(fd->set_title_attr), MYFRAME_TitleFHueSet);
+                    break;
+                case MYFRAME_TitleUHue_ID :
+					set_string_value (&(fd->title_uhue), item.data.string, &(fd->set_title_attr), MYFRAME_TitleUHueSet);
+                    break;
+                case MYFRAME_TitleSHue_ID :
+					set_string_value (&(fd->title_shue), item.data.string, &(fd->set_title_attr), MYFRAME_TitleSHueSet);
+                    break;
+                case MYFRAME_TitleFSat_ID :
+                    fd->title_fsat = item.data.integer;
+                    set_flags( fd->set_title_attr, MYFRAME_TitleFSatSet );
+                    break;
+                case MYFRAME_TitleUSat_ID :
+                    fd->title_usat = item.data.integer;
+                    set_flags( fd->set_title_attr, MYFRAME_TitleUSatSet );
+                    break;
+                case MYFRAME_TitleSSat_ID :
+                    fd->title_ssat = item.data.integer;
+                    set_flags( fd->set_title_attr, MYFRAME_TitleSSatSet );
+                    break;
+                case MYFRAME_TitleHSpacing_ID :
+                    fd->title_h_spacing = item.data.integer;
+                    set_flags( fd->set_title_attr, MYFRAME_TitleHSpacingSet );
+                    break;
+                case MYFRAME_TitleVSpacing_ID :
+                    fd->title_v_spacing = item.data.integer;
+                    set_flags( fd->set_title_attr, MYFRAME_TitleVSpacingSet );
+                    break;
 
                 case MYFRAME_Inherit_ID :
                     {
