@@ -51,16 +51,17 @@ SyntaxDef* TopLevelSyntaxes[] =
 	&WinTabsSyntax,
     &AnimateSyntax,
     &AudioSyntax,
+	&ArrangeSyntax,
 	NULL
 };	 
 
 const char *StandardSourceEntries[] = 
 {
-	"_synopsis",	
-	"_overview",	   
-#define OPENING_PARTS_END   2	 
-	"_examples",	   
 	"_related",	   
+	"_synopsis",	
+#define OPENING_PARTS_END   2	 
+	"_overview",	   
+	"_examples",	   
 	"_footnotes",	   
 	NULL
 };
@@ -136,8 +137,9 @@ ASApiSourceDescr libAfterImage_Sources[] =
 
 
 const char *HTML_CSS_File = "html_styles.css" ;
+const char *FAQ_HTML_CSS_File = "faq_html_styles.css" ;
 static const char *HTML_DATA_BACKGROUND_File = "background.jpg" ;
-static const char *HTML_HELP_BACKGROUND_File = NULL ;
+/*static const char *HTML_HELP_BACKGROUND_File = NULL ; */
 const char *CurrHtmlBackFile = NULL ;
 
 ASHashTable *DocBookVocabulary = NULL ;
@@ -160,6 +162,7 @@ void check_syntax_source( const char *source_dir, SyntaxDef *syntax, Bool module
 void gen_syntax_doc( const char *source_dir, const char *dest_dir, SyntaxDef *syntax, ASDocType doc_type );
 void gen_glossary( const char *dest_dir, const char *file, ASDocType doc_type );
 void gen_index( const char *dest_dir, const char *file, ASDocType doc_type, Bool user_docs );
+void gen_faq_doc( const char *source_dir, const char *dest_dir, ASDocType doc_type );
 
 /*************************************************************************/
 /*************************************************************************/
@@ -185,6 +188,25 @@ DeadPipe (int foo)
     exit (0);
 }
 
+void
+asdocgen_usage (void)
+{
+	printf ("Usage:\n"
+			"%s\t\t[-t |--target plain|text|html|php|xml|nroff|source] [-s | -css stylesheets_file]\n"
+			"\t\t\t[--faq-css stylesheets_file] [--html-data-back background] [-d | --data]\n"
+			"\t\t\t[-S | --source source_dir] [-D | --dst destination_dir]\n"
+			"-t | --target 		- selects oputput file format\n"
+			"-s | --css 		- selects which file to get HTML style sheets from\n"
+			"     --faq-css    	- selects which file to get HTML style sheets from for FAQs\n"
+			"	  --html-data-back - which image file to use as HTML background ( default background.jpg )\n"
+			"-d | --data        - generate HTML catalogue of image/data files\n"
+			"-S | --source      - specifies dir to read XML source or data source from\n"
+			"-D | --dst         - specifies destination directory - where to wriote stuff to\n",
+			MyName);
+	exit (0);
+}
+
+
 int
 main (int argc, char **argv)
 {
@@ -194,7 +216,9 @@ main (int argc, char **argv)
 	Bool do_data = False;
 	ASDocType target_type = DocType_Source ;
 	/* Save our program name - for error messages */
-    InitMyApp (CLASS_ASDOCGEN, argc, argv, NULL, NULL, 0 );
+	set_DeadPipe_handler(DeadPipe);
+    InitMyApp (CLASS_ASDOCGEN, argc, argv, asdocgen_usage, NULL, 0 );
+	LinkAfterStepConfig();
 	InitSession();
     for( i = 1 ; i< argc ; ++i)
 	{
@@ -222,6 +246,10 @@ main (int argc, char **argv)
 			{
 				++i ;				
 				HTML_CSS_File = argv[i] ;
+			}else if( strcmp( argv[i], "--faq-css" ) == 0 && i+1 < argc && argv[i+1] != NULL ) 
+			{
+				++i ;				
+				FAQ_HTML_CSS_File = argv[i] ;
 			}else if( strcmp( argv[i], "--html-data-back" ) == 0 && i+1 < argc && argv[i+1] != NULL ) 
 			{
 				++i ;				
@@ -250,7 +278,7 @@ main (int argc, char **argv)
 
 #if 0
 
-    ConnectAfterStep ( mask_reg);
+    ConnectAfterStep ( mask_reg, 0);
 	
   	SendInfo ( "Nop \"\"", 0);
 #endif
@@ -366,6 +394,7 @@ main (int argc, char **argv)
 			
 			if( DocGenerationPass == 0 ) 
 			{	
+				gen_faq_doc( source_dir, destination_dir, target_type );
 				gen_glossary( destination_dir, "Glossary", target_type );
 				gen_index( destination_dir, "index", target_type, True );
 			}
@@ -373,7 +402,7 @@ main (int argc, char **argv)
 		}
 		flush_ashash( Glossary );
 		flush_ashash( Index );
-
+		
 		GlossaryName = APIGlossaryName ; 
 		TopicIndexName = APITopicIndexName ; 
 		Links = APILinks;
@@ -400,6 +429,8 @@ main (int argc, char **argv)
 			flush_ashash( Glossary );
 			flush_ashash( Index );
 		}		  
+
+
 	}		 
 	
 	if( dpy )   
@@ -577,8 +608,8 @@ check_syntax_source( const char *source_dir, SyntaxDef *syntax, Bool module )
 			if( !get_flags( syntax->terms[i].flags, TF_OBSOLETE) )
 			{	
 				SyntaxDef *sub_syntax = syntax->terms[i].sub_syntax ; 
-				if( sub_syntax == &PopupFuncSyntax ) 
-					sub_syntax = &FuncSyntax ;
+				if( sub_syntax == pPopupFuncSyntax ) 
+					sub_syntax = pFuncSyntax ;
 				if (sub_syntax)
 					check_syntax_source( source_dir, sub_syntax, False );
 				if( isalnum( syntax->terms[i].keyword[0] ) )					
@@ -704,8 +735,8 @@ gen_syntax_doc( const char *source_dir, const char *dest_dir, SyntaxDef *syntax,
 		for (i = 0; syntax->terms[i].keyword; i++)
 		{	
 			SyntaxDef *sub_syntax = syntax->terms[i].sub_syntax ; 
-			if( sub_syntax == &PopupFuncSyntax ) 
-				sub_syntax = &FuncSyntax ;
+			if( sub_syntax == pPopupFuncSyntax ) 
+				sub_syntax = pFuncSyntax ;
 			
 			if (sub_syntax)
 				gen_syntax_doc( source_dir, dest_dir, sub_syntax, doc_type );
@@ -756,6 +787,43 @@ gen_syntax_doc( const char *source_dir, const char *dest_dir, SyntaxDef *syntax,
 	free( syntax_dir );
 }
 
+void 
+gen_faq_doc( const char *source_dir, const char *dest_dir, ASDocType doc_type )
+{
+	ASXMLInterpreterState state;
+	char *faq_dir = NULL ;
+	ASFlagType doc_class_mask = DOC_CLASS_None	;
+	struct direntry  **list = NULL;
+	int list_len, i ;
+
+	faq_dir = make_file_name( source_dir, "FAQ" );
+
+	if( !start_doc_file( dest_dir, "afterstep_faq", NULL, doc_type, 
+						 "afterstep_faq", 
+						 "AfterStep FAQ",
+						 "This document is an ever growing set of questions, statements, ideas and complaints about AfterStep version 2.0", 
+						 &state, doc_class_mask, DocClass_FAQ ) )	 
+		return ;
+	
+	/* BODY *************************************************************************/
+	set_flags( state.flags, ASXMLI_OrderSections );
+	list_len = my_scandir ((char*)faq_dir, &list, ignore_dots, NULL);
+	for (i = 0; i < list_len; i++)
+	{	
+		if ( !S_ISDIR (list[i]->d_mode) )
+			convert_xml_file( faq_dir, list[i]->d_name, &state );
+		free(list[i]);
+	}
+	if( list ) 
+		free( list );   
+	
+	/* FOOTER ***********************************************************************/
+	end_doc_file( &state );	 	
+	
+	free( faq_dir );
+}
+
+
 void 
 gen_glossary( const char *dest_dir, const char *file, ASDocType doc_type )
 {
