@@ -34,6 +34,7 @@ struct MenuItem;
 struct ASEvent;
 struct ASFeel;
 struct MyLook;
+struct ASHintWindow;
 
 struct ASWindow;
 typedef struct ASInternalWindow
@@ -511,7 +512,7 @@ void display_progress( Bool new_line, const char *msg_format, ... );
 
 
 /*************************** decorations.c ********************************/
-inline ASOrientation* get_orientation_data( ASWindow *asw );
+ASOrientation* get_orientation_data( ASWindow *asw );
 void grab_aswindow_buttons( ASWindow *asw, Bool focused );
 
 int check_allowed_function2 (int func, ASHints *hints);
@@ -528,7 +529,7 @@ void DispatchEvent  ( struct ASEvent *event, Bool deferred );
 void HandleEvents   ();
 void InteractiveMoveLoop ();
 void WaitForButtonsUpLoop ();
-Bool WaitEventLoop( struct ASEvent *event, int finish_event_type, long timeout );
+Bool WaitEventLoop( struct ASEvent *event, int finish_event_type, long timeout, struct ASHintWindow *hint );
 Bool IsClickLoop( struct ASEvent *event, unsigned int end_mask, unsigned int click_time );
 ASWindow *WaitWindowLoop( char *pattern, long timeout );
 void ConfigureNotifyLoop();
@@ -644,6 +645,7 @@ void broadcast_config (send_data_type event_type, ASWindow * t);
 void HandleModuleInOut(unsigned int channel, Bool has_input, Bool has_output);
 
 void KillModuleByName (char *name);
+int FindModuleByName (char *name);
 void DeadPipe (int nonsense);
 void ShutdownModules(Bool dont_free_memory);
 
@@ -693,7 +695,7 @@ Bool set_window_wm_state( ASWindow *asw, Bool iconify );
 Bool make_aswindow_visible( ASWindow *asw, Bool deiconify );
 void change_aswindow_layer( ASWindow *asw, int layer );
 void quietly_reparent_aswindow( ASWindow *asw, Window dst, Bool user_root_pos );
-void change_aswindow_desktop( ASWindow *asw, int new_desk );
+void change_aswindow_desktop( ASWindow *asw, int new_desk, Bool force );
 void toggle_aswindow_status( ASWindow *asw, ASFlagType flags );
 Bool check_window_offscreen( ASWindow *asw );
 
